summaryrefslogtreecommitdiff
path: root/internal/handlers/handlers.go
diff options
context:
space:
mode:
authorPeter Stone <thepeterstone@gmail.com>2026-01-20 21:38:18 -1000
committerPeter Stone <thepeterstone@gmail.com>2026-01-20 21:38:18 -1000
commitdd4689a71de8f1c0b5a2d483827411a9645ad66a (patch)
treedca7bae311ceeac5eddae2213834d36c576676d4 /internal/handlers/handlers.go
parenta38ce269cc9283556621b5447eb3a0caf697eae9 (diff)
UI improvements and bug fixes
- Gray out overdue tasks (past today) - Sort tasks with specific times before midnight-due tasks - Fix timezone bug in quick add (use local timezone) - Remove "Personal Dashboard" header, minimal refresh/logout bar - Change Todoist icon from checkmark to red circle - Show due time when set (not just date) - Compact task list styling Co-Authored-By: Claude Opus 4.5 <noreply@anthropic.com>
Diffstat (limited to 'internal/handlers/handlers.go')
-rw-r--r--internal/handlers/handlers.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/handlers/handlers.go b/internal/handlers/handlers.go
index 8d809ae..e4d6457 100644
--- a/internal/handlers/handlers.go
+++ b/internal/handlers/handlers.go
@@ -762,10 +762,10 @@ func (h *Handler) HandleUnifiedAdd(w http.ResponseWriter, r *http.Request) {
return
}
// Parse due date if provided
var dueDate *time.Time
if dueDateStr != "" {
- parsed, err := time.Parse("2006-01-02", dueDateStr)
+ parsed, err := time.ParseInLocation("2006-01-02", dueDateStr, time.Local)
if err == nil {
dueDate = &parsed
}
@@ -762,10 +762,10 @@ func (h *Handler) HandleUnifiedAdd(w http.ResponseWriter, r *http.Request) {
return
}
- // Parse due date if provided
+ // Parse due date if provided (use local timezone)
var dueDate *time.Time
if dueDateStr != "" {